Class Documentation
===================

Mailbox
-------

.. autoclass:: django_mailbox.models.Mailbox
   :members:
   :undoc-members:

Message
-------

.. autoclass:: django_mailbox.models.Message
   :members:
   :undoc-members:

Message Attachment
------------------

.. autoclass:: django_mailbox.models.MessageAttachment
   :members:
   :undoc-members:
